@@ -1,4 +1,4 @@
-﻿### function integrating Traktion force microscopy into a clcikpoints database
+﻿# function integrating Traction force microscopy into a clickpoints database
 
 import os
 import warnings
@@ -17,7 +17,6 @@ from skimage.morphology import label
 from tqdm import tqdm
 
 
-
 class Mask_Error(Exception):
     pass
 
@@ -84,15 +83,15 @@ class cells_masks():
                     coords_final = np.where(np.logical_and(mask == index, new_mask))
                     # extracting only one mask type in only one object
                     warn = check_mask_size(mask, self.warn_thresh, print_out=True, mask_name=mask_name, frame=frame)
-                    self._masks_dict[frame][obj_id][mask_name] = (
-                        coords_final, shape)  # writing to dict only the coordinates of true values
+                    # writing to dict only the coordinates of true values
+                    self._masks_dict[frame][obj_id][mask_name] = (coords_final, shape)
                     self._warns_dict[frame][obj_id][mask_name] = warn + " " * (warn != "") + warn_edge
                     self._masks_dict[frame][obj_id]["com"] = r.centroid
 
     def get_com_frame(self, frame):
         ret = []
         for cell_id in self.masks_dict[frame].keys():
-            com = self.masks_dict[frame][cell_id]["com"]  # do i need to use the property here??
+            com = self.masks_dict[frame][cell_id]["com"]
             ret.append((cell_id, com))
         return ret
 
@@ -100,7 +99,7 @@ class cells_masks():
         # takes about 0.2 seconds for one type of mask
         # note: small objects have already been removed
         mask = None
-        ind_shape = self.masks_dict[frame][cell_id][mtype]  # do i need to use the property here??
+        ind_shape = self.masks_dict[frame][cell_id][mtype]
         if isinstance(ind_shape, tuple):
             indices = ind_shape[0]
             shape = ind_shape[1]
@@ -120,8 +119,9 @@ class cells_masks():
                 raise Mask_Error("no mask found in frame %s for type %s" % (str(frame), mtype))
         return mask
 
-    def reconstruct_masks_frame(self, frame, mtype="mask", raise_error=True, fill_holes=False, obj_ids=[], indices=None):
-        # retrieves the a list of all masks and cell ids in one frame
+    def reconstruct_masks_frame(self, frame, mtype="mask", raise_error=True, fill_holes=False, obj_ids=[],
+                                indices=None):
+        # retrieves the list of all masks and cell ids in one frame
         ret = []
         mtypes = make_iterable(mtype)
         for cell_id in self.masks_dict[frame].keys():
@@ -172,7 +172,7 @@ def write_output_file(values, value_type, file_path, new_file=False):
                     break
     if value_type == "parameters":
         with open(file_path, "w+") as f:
-            f.write("analysis_paramters\n")
+            f.write("analysis_parameters\n")
             for parameter, value in values.items():
                 if parameter not in ["mask_properties", "FEM_mode_id", "fig_parameters", "cv_pad"]:
                     f.write(parameter + "\t" + str(value) + "\n")
@@ -227,8 +227,6 @@ def warn_small_FEM_area(mask_area, threshold):
     return warn
 
 
-
-
 def check_small_or_empty_mask(mask, frame, mtype, warn_thresh=None, raise_error=True, add_str_error="",
                               add_str_warn=""):
     # checking if mask is empty
@@ -245,18 +243,22 @@ def check_small_or_empty_mask(mask, frame, mtype, warn_thresh=None, raise_error=
 
 
 def try_to_load_deformation(path, frame, warn=False):
-    '''
-    loading the deformations fro a given frame. If deformations are not found either raises an error
+    """
+    loading the deformations from a given frame. If deformations are not found either raises an error
     or a warning (warn=True) and returns None for u and v
 
     :param path:
     :param frame:
     :param warn:
     :return:
-    '''
+    """
     try:
-        u = np.load(os.path.join(path, frame + "u.npy"))
-        v = np.load(os.path.join(path, frame + "v.npy"))
+        if default_parameters["output type"] == "npy":
+            u = np.load(os.path.join(path, frame + "u.npy"))
+            v = np.load(os.path.join(path, frame + "v.npy"))
+        if default_parameters["output type"] == "txt":
+            u = np.loadtxt(os.path.join(path, frame + "u.txt"))
+            v = np.loadtxt(os.path.join(path, frame + "v.txt"))
     except FileNotFoundError:
         if warn:
             warnings.warn("no deformations found for frame " + frame)
@@ -267,7 +269,7 @@ def try_to_load_deformation(path, frame, warn=False):
 
 
 def try_to_load_traction(path, frame, warn=False):
-    '''
+    """
     loading the tractions from a given frame. If tractions are not found either raises an error
     or a warning (warn=True) and returns None for u and v
 
@@ -275,10 +277,14 @@ def try_to_load_traction(path, frame, warn=False):
     :param frame:
     :param warn:
     :return:
-    '''
+    """
     try:
-        t_x = np.load(os.path.join(path, frame + "tx.npy"))
-        t_y = np.load(os.path.join(path, frame + "ty.npy"))
+        if default_parameters["output type"] == "npy":
+            t_x = np.load(os.path.join(path, frame + "tx.npy"))
+            t_y = np.load(os.path.join(path, frame + "ty.npy"))
+        if default_parameters["output type"] == "txt":
+            t_x = np.loadtxt(os.path.join(path, frame + "tx.txt"))
+            t_y = np.loadtxt(os.path.join(path, frame + "ty.txt"))
     except FileNotFoundError as e:
         if warn:
             warnings.warn("no traction forces found for frame " + frame)
@@ -289,11 +295,11 @@ def try_to_load_traction(path, frame, warn=False):
 
 
 def create_layers_on_demand(db, db_info, layer_list):
-    '''
-    :param db: clickpointsw database
+    """
+    :param db: clickpoints database
     :param layer_list: list of layer names that should be created
     :return:
-    '''
+    """
     layer_list = make_iterable(layer_list)
     if any([l not in db_info["layers"] for l in layer_list]):
         base_layer = db.getLayer(id=1)
@@ -329,7 +335,7 @@ def split_list_str(string, **kwargs):
     return list_obj
 
 
-def get_option_wrapper(db, key, unpack_funct=None, empty_return=list, **kwargs):
+def get_option_wrapper(db, key, unpack_funct= None, empty_return= list, **kwargs):
     try:
         if unpack_funct:
             return unpack_funct(db.table_option.select().where(db.table_option.key == key).get().value, **kwargs)
@@ -358,7 +364,7 @@ def get_db_info_for_analysis(db):
     if path == ".":
         path = os.path.split(db._database_filename)[0]
 
-    # TODO: think about optimizing that// this esentially loads one image per frame each time it is called
+    # TODO: think about optimizing that// this essentially loads one image per frame each time it is called
     im_shapes = {}  # exact list of image shapes
     for frame in unique_frames:
         images = db.getImages(frame=frames_ref_dict[frame])
@@ -406,7 +412,7 @@ def add_plot(plot_type, values, plot_function, frame, db_info, parameter_dict, d
                                                 figtype=plot_type)
         fig, ax = plot_function(*values, **fig_parameters_use)
 
-        # saving the the plot
+        # saving the plot
         print("saving to " + os.path.join(db_info["path"], frame + file_name))
         fig.savefig(os.path.join(db_info["path"], frame + file_name), facecolor=fig.get_facecolor(),
                     edgecolor=fig.get_facecolor(), dpi=fig_parameters_use["resolution"])
@@ -414,21 +420,23 @@ def add_plot(plot_type, values, plot_function, frame, db_info, parameter_dict, d
         # adding the plot to the database
         write_image(db, layer=layer, sort_index=db_info["frames_ref_dict"][frame], filename=frame + file_name)
 
+
 def check_empty_mask(mask, mtype="---", frame="---", obj_id="---", add_str_error="", raise_error=False):
     if not isinstance(mask, np.ndarray):
-        wrong=True
+        wrong = True
     elif np.sum(mask) == 0:
         wrong = True
     else:
-        wrong=False
+        wrong = False
     if wrong:
         string = "couldn't identify mask %s in frame %s patch %s" % (str(mtype), str(frame), str(obj_id))
         if raise_error:
-            raise Mask_Error(string +  " " + add_str_error)
+            raise Mask_Error(string + " " + add_str_error)
         else:
             print(string)
     return wrong
 
+
 def calc_on_area(frame, res_dict, parameter_dict, label, masks, mask_types=None, obj_ids=[], x=None, y=None,
                  sumtype="abs", add_cut_factor=None, db_info=None, label2=None):
     fill_holes = True if parameter_dict["FEM_mode"] == "colony" else False
@@ -467,23 +475,21 @@ def calc_on_area(frame, res_dict, parameter_dict, label, masks, mask_types=None,
                 [obj_id, coefficient_of_variation(mask_int, x, border_pad), warn])
 
 
-
 def general_properties(frame, parameter_dict, res_dict, db, db_info=None, masks=None, **kwargs):
-
-    '''
+    """
     Number of cells, area of the cell colony...
     :param frame:
     :param parameter_dict:
     :param res_dict:
     :param db:
     :return:
-    '''
+    """
 
     # area of the cells/cell colony
     # retrieve which masks should be used to calculate the area
     use_type = "area_colony" if parameter_dict["FEM_mode"] == "colony" else "area_layer"
     mtypes = [m for m in db_info["mask_types"] if m in get_masks_by_key(default_parameters, "use", use_type)]
-    # place holder for shape if not defined in defo-shape, needed for counting cells
+    # placeholder for shape if not defined in defo-shape, needed for counting cells
     int_shape = db_info["defo_shape"] if "defo_shape" in db_info.keys() else (int(db_info["im_shape"][frame][0] * 0.2),
                                                                               int(db_info["im_shape"][frame][1] * 0.2))
     # calculate the area of each mask
@@ -524,6 +530,8 @@ def simple_shift_correction(frame, parameter_dict, res_dict, db, db_info=None, *
         im_m_path = find_full_im_path(im_m, db_info["path"])
         n_frames = 3
     except KeyError:
+        image_membrane = None
+        im_m_path = None
         n_frames = 2
 
     # get paths for saving later
@@ -534,17 +542,15 @@ def simple_shift_correction(frame, parameter_dict, res_dict, db, db_info=None, *
     if n_frames == 2:
         b_save, a_save, [], drift = correct_stage_drift(image_before, image_after,
                                                         additional_images=[])
-    if n_frames == 3:
+    else:  # n_frames == 3
         b_save, a_save, [m_save], drift = correct_stage_drift(image_before, image_after,
                                                               additional_images=[image_membrane])
+        m_save.save(im_m_path)
 
     print("\nframe %s: found drift of %s" % (frame, str(np.round(drift, 3))))
     b_save.save(im_b_path)
     a_save.save(im_a_path)
 
-    if n_frames == 3:
-        m_save.save(im_m_path)
-
 
 def simple_segmentation(frame, parameter_dict, res_dict, db, db_info=None, masks=None, seg_threshold=0,
                         seg_type="cell_area", im_filter=None, **kwargs):
@@ -597,12 +603,12 @@ def cover_entire_image_with_mask(frame, parameter_dict, res_dict, db, db_info=No
         data = np.ones(db_info["im_shape"][frame]) * index
         db.setMask(frame=db_info["frames_ref_dict"][frame], data=data.astype(np.uint8))
     # marking the outer perimeter of the image with the mask
-    # perimeter directly at the edge doesnt work for binary fill holes method later one
+    # perimeter directly at the edge doesn't work for binary fill holes method later one
     # perimeter is set index-pixels distant to the image edge, so that you can set multiple masks with this method
     if mode == "encircle image":
         data = try_mask_load(db, db_info["frames_ref_dict"][frame], raise_error=False, mtype="all", ret_type="zeros")
-        data[(index, -(index+1)), index:-index] = index
-        data[index:-index, (index, -(index+1))] = index
+        data[(index, -(index + 1)), index:-index] = index
+        data[index:-index, (index, -(index + 1))] = index
         db.setMask(frame=db_info["frames_ref_dict"][frame], data=data.astype(np.uint8))
 
     return None, frame
@@ -620,20 +626,29 @@ def deformation(frame, parameter_dict, res_dict, db, db_info=None, masks=None, *
                                                  window_size_pix, overlap_pix,
                                                  std_factor=parameter_dict["std_factor"])
     db_info["defo_shape"] = u.shape
-    res_dict[frame]["sum deformations image"].append(["image", np.sum(np.sqrt(u ** 2 + v ** 2)), ""])  # propably remove that
+    res_dict[frame]["sum deformations image"].append(["image", np.sum(np.sqrt(u ** 2 + v ** 2)), ""])
 
     # adding plot of deformation field to the database
     add_plot("deformation", (u, v), show_quiver, frame, db_info, parameter_dict, db)
 
     # saving raw files
-    np.save(os.path.join(db_info["path"], frame + "u.npy"), u)
-    np.save(os.path.join(db_info["path"], frame + "v.npy"), v)
+    save_array(db_info["path"], frame + "u", u)
+    save_array(db_info["path"], frame + "v", v)
     # summing deformation over certain areas
     mtypes = [m for m in db_info["mask_types"] if m in get_masks_by_key(default_parameters, "use", "defo")]
     calc_on_area(frame, res_dict, parameter_dict, "sum deformations", masks, mask_types=mtypes, x=u, y=v, sumtype="abs")
     return None, frame
 
 
+def save_array(folder, name, array):
+    if default_parameters["output type"] == "txt":
+        np.savetxt(os.path.join(folder, name + ".txt"), array)
+    elif default_parameters["output type"] == "npy":
+        np.save(os.path.join(folder, name + ".npy"), array)
+    else:
+        raise ValueError("Invalid 'output type'. Use 'txt' or 'npy'")
+
+
 def get_contractillity_contractile_energy(frame, parameter_dict, res_dict, db, db_info=None, masks=None, **kwargs):
     u, v = try_to_load_deformation(db_info["path"], frame, warn=True)
     t_x, t_y = try_to_load_traction(db_info["path"], frame, warn=False)
@@ -648,7 +663,8 @@ def get_contractillity_contractile_energy(frame, parameter_dict, res_dict, db, d
         energy_points = strain_energy_points(u, v, t_x, t_y, parameter_dict["pixelsize"],
                                              ps_new)  # contractile energy at any point
         # plotting contractile energy (only happens if enable in default_fig_parameters)
-        add_plot("energy_points", [energy_points/((ps_new*10**-6)**2)], show_map_clickpoints, frame, db_info, parameter_dict, db)
+        add_plot("energy_points", [energy_points / ((ps_new * 10 ** -6) ** 2)], show_map_clickpoints, frame, db_info,
+                 parameter_dict, db)
 
     # iterating though mask that are selected for summation
     mask_iter = masks.reconstruct_masks_frame(frame, mtypes, raise_error=False, fill_holes=True)
@@ -672,8 +688,8 @@ def get_contractillity_contractile_energy(frame, parameter_dict, res_dict, db, d
         # calculate contractile energy if deformations are provided
         if isinstance(u, np.ndarray):
             check_shape(u, t_x)
-            contr_energy = np.sum(energy_points[mask_int])  # sum of contractile energy on on mask
-            #+ default_parameters["mask_properties"][mtype]["label"]
+            contr_energy = np.sum(energy_points[mask_int])  # sum of contractile energy on mask
+            # + default_parameters["mask_properties"][mtype]["label"]
             res_dict[frame]["strain energy"].append(
                 [obj_id, contr_energy, warn])
         print("strain energy=", round_flexible(contr_energy), "contractility=", round_flexible(contractile_force))
@@ -682,7 +698,7 @@ def get_contractillity_contractile_energy(frame, parameter_dict, res_dict, db, d
 
 
 def traction_force(frame, parameter_dict, res_dict, db, db_info=None, masks=None, **kwargs):
-    # trying to laod deformation
+    # trying to load deformation
     u, v = try_to_load_deformation(db_info["path"], frame, warn=False)
     db_info["defo_shape"] = u.shape
     ps_new = parameter_dict["pixelsize"] * np.mean(np.array(db_info["im_shape"][frame]) / np.array(u.shape))
@@ -693,21 +709,21 @@ def traction_force(frame, parameter_dict, res_dict, db, db_info=None, masks=None
                                pixelsize2=ps_new,
                                h=parameter_dict["h"], young=parameter_dict["young"],
                                sigma=parameter_dict["sigma"],
-                               filter=parameter_dict["filter_type"], fs=parameter_dict["filter_size"])
+                               spatial_filter=parameter_dict["filter_type"], fs=parameter_dict["filter_size"])
 
     if parameter_dict["TFM_mode"] == "infinite_thickness":
         tx, ty = ffttc_traction(u, v, pixelsize1=parameter_dict["pixelsize"],
                                 pixelsize2=ps_new,
                                 young=parameter_dict["young"],
                                 sigma=parameter_dict["sigma"],
-                                filter=parameter_dict["filter_type"], fs=parameter_dict["filter_size"])
+                                spatial_filter=parameter_dict["filter_type"], fs=parameter_dict["filter_size"])
 
     # add a plot of the traction filed to the database
     add_plot("traction", (tx, ty), show_quiver, frame, db_info, parameter_dict, db)
 
     # saving raw files
-    np.save(os.path.join(db_info["path"], frame + "tx.npy"), tx)
-    np.save(os.path.join(db_info["path"], frame + "ty.npy"), ty)
+    save_array(db_info["path"], frame + "tx", tx)
+    save_array(db_info["path"], frame + "ty", ty)
 
     mtypes = [m for m in db_info["mask_types"] if m in get_masks_by_key(default_parameters, "use", "forces")]
     calc_on_area(frame, res_dict, parameter_dict, "sum traction forces", masks, mask_types=mtypes, x=tx, y=ty,
@@ -716,32 +732,32 @@ def traction_force(frame, parameter_dict, res_dict, db, db_info=None, masks=None
 
 
 def FEM_grid_setup(frame, parameter_dict, mask_grid, db_info=None, warn="", **kwargs):
-    '''
+    """
     :param frame:
     :param parameter_dict:
     :param db:
     :param db_info:
     :param kwargs:
     :return:
-    '''
+    """
 
     # loading forces and update shape info
     t_x, t_y = try_to_load_traction(db_info["path"], frame, warn=False)
     db_info["defo_shape"] = t_x.shape  # pixelsize of fem grid in µm
     ps_new = parameter_dict["pixelsize"] * np.mean(np.array(db_info["im_shape"][frame]) / np.array(t_x.shape))
-    # preparig the mask
+    # preparing the mask
     mask_area = prepare_mask_FEM(mask_grid, t_x.shape)  # area for FEM analysis
     warn_grid = warn_small_FEM_area(mask_area, threshold=1000)
     warn = warn + " " + warn_grid
 
-    # FEM grid setupplt.
+    # FEM grid setup
     # preparing forces
     f_x = t_x * ((ps_new * (10 ** -6)) ** 2)  # point force for each node from tractions
     f_y = t_y * ((ps_new * (10 ** -6)) ** 2)
     if parameter_dict["FEM_mode"] == "colony":
         # using mask for grid setup
         # trying to load cell colony mask, raise error if not found
-        # coorecting force for torque and net force
+        # correcting force for torque and net force
         f_x_c2, f_y_c2, p = correct_forces(f_x, f_y, mask_area)
         # get_torque1(f_y,f_x,mask_area)
         nodes, elements, loads, mats = grid_setup(mask_area, -f_x_c2, -f_y_c2, 1, sigma=parameter_dict["sigma_cells"],
@@ -815,7 +831,7 @@ def FEM_analysis_borders(frame, res_dict, db, db_info, parameter_dict, stress_te
     res_dict[frame]["average shear line tension"].append([obj_id, line_tension_sh[1], warn])
     res_dict[frame]["std shear line tension"].append([obj_id, line_tension_sh[2], ""])
 
-    # currently cells are not detected in cell layer mode// could ne implemented though...
+    # currently cells are not detected in cell layer mode
     if parameter_dict["FEM_mode"] == "colony":
         avg_cell_force = mean_stress_vector_norm(lines_interpol, borders, norm_level="cells", vtype="t_vecs",
                                                  exclude_colony_edge=True)
@@ -842,7 +858,7 @@ def FEM_full_analysis(frame, parameter_dict, res_dict, db, db_info=None, masks=N
     FEM_type = "FEM_layer" if parameter_dict["FEM_mode"] == "cell layer" else "FEM_colony"
     # masks that make up the FEM_are
     FEM_area_masks = get_masks_by_key(parameter_dict, "use", FEM_type)
-    # add relevant masks, usefull in cell layer mode
+    # add relevant masks, useful in cell layer mode
     if FEM_type == "cell layer":
         mask_iter_grid = masks.reconstruct_masks_frame_add(frame, FEM_area_masks, raise_error=False, fill_holes=True)
     else:
@@ -856,7 +872,10 @@ def FEM_full_analysis(frame, parameter_dict, res_dict, db, db_info=None, masks=N
                                                                                db_info=db_info, **kwargs)
         # FEM solution
         UG_sol, stress_tensor = FEM_simulation(nodes, elements, loads, mats, mask_area)
-        np.save(os.path.join(db_info["path"], frame + "stress_tensor.npy"), stress_tensor / (ps_new * 10**-6))
+        save_array(db_info["path"], frame + "stress_tensor_xx", stress_tensor[:, :, 0, 0] / (ps_new * 10 ** -6))
+        save_array(db_info["path"], frame + "stress_tensor_xy", stress_tensor[:, :, 1, 0] / (ps_new * 10 ** -6))
+        save_array(db_info["path"], frame + "stress_tensor_yx", stress_tensor[:, :, 0, 1] / (ps_new * 10 ** -6))
+        save_array(db_info["path"], frame + "stress_tensor_yy", stress_tensor[:, :, 1, 1] / (ps_new * 10 ** -6))
 
         # analyzing stresses and stress distribution
         mean_normal_stress = FEM_analysis_average_stresses(frame, res_dict, parameter_dict, db, db_info, stress_tensor,
@@ -916,18 +935,18 @@ def provide_basic_objects(db, frames, parameter_dict, db_info, masks, res_dict):
 
 def apply_to_frames(db, parameter_dict, analysis_function, leave_basics=False, res_dict=None, frames=[], db_info=None,
                     masks=None, **kwargs):
-    '''
+    """
     wrapper to apply analysis function on all frames
     :param db: clickpoints database
     :param parameter_dict: parameters for piv deformation calculation: (window size, overlap), sigma and Young's modulus
-    of the gel (or of the cell sheet when applying FEM), hight of the gel
+    of the gel (or of the cell sheet when applying FEM), height of the gel
     :param func: function that is analyzed
     :param frames: list f frames (of the cdb database) to be analyze e.g [0,1,2]
     :param db_info: dictionary with the keys "path","frames_ref_dict","im_shape","file_order" as constructed from
     get db_info_for_analysis
     :param res_dict: dictionary of results to be filled up adn appended
     :return:
-    '''
+    """
 
     frames = make_iterable(frames)
     if not leave_basics:
@@ -944,10 +963,9 @@ def apply_to_frames(db, parameter_dict, analysis_function, leave_basics=False, r
     return db_info, masks, res_dict
 
 
-### code to work on clickpoint outside of the addon
+# code to work on clickpoints outside the addon
 if __name__ == "__main__":
-
-    ## setting up necessary paramteres
+    # setting up necessary parameters
     # db=clickpoints.DataFile("/home/user/Desktop/Monolayers_new_images/monolayers_new_images/KO_DC1_tomatoshift/database.cdb","r")
     db = clickpoints.DataFile("/home/andy/test_data_pyTFM/KOshift/database.cdb", "r")
     parameter_dict = default_parameters
@@ -956,19 +974,13 @@ if __name__ == "__main__":
 
     # db_info, masks, res_dict = apply_to_frames(db, parameter_dict, deformation, res_dict, frames="12",
     #                                            db_info=db_info, masks=None)
-    #db_info, masks, res_dict = apply_to_frames(db, parameter_dict, general_properties, res_dict=res_dict,
-   #                                            frames=all_frames,
+    # db_info, masks, res_dict = apply_to_frames(db, parameter_dict, general_properties, res_dict=res_dict,
+    #                                            frames=all_frames,
     #                                           db_info=db_info, masks=None)
     db_info, masks, res_dict = apply_to_frames(db, parameter_dict, FEM_full_analysis, res_dict=res_dict, frames="01",
                                                db_info=db_info, masks=None)
-
-    # parameter_dict["filter_type"]=None
-# default_fig_parameters["file_names"]["traction"] = "t_none.png"
-# db_info, masks, res_dict = apply_to_frames(db, parameter_dict, traction_force, res_dict, frames="12",
-#                                       db_info=db_info, masks=None)
-
-'''
-    ###### problem: produces empty entries when try to access non-exisitng str
+    """
+    ###### problem: produces empty entries when try to access non-existing str
     masks = cells_masks(all_frames, db, db_info, parameter_dict)
     db_info, masks, res_dict = apply_to_frames(db, parameter_dict, general_properties, res_dict, frames="01",
                                                db_info=db_info, masks=masks)
@@ -987,6 +999,4 @@ if __name__ == "__main__":
 
     write_output_file(res_dict, "results", "/home/user/Desktop/backup_from_harddrive/data_traction_force_microscopy/WT_vs_KO_images/WTshift/out_test.txt",new_file=True)
         # calculating the deformation field and adding to data base
-'''
-#TDOD: deal with oroblems when database is moved around/ folders are renamed --> make option with this directory
-#TODO insert tables as images for read the docs
\ No newline at end of file
+    """
